diff --git a/AppData/ComLib.cs b/AppData/ComLib.cs
index 379213d..fdb8ea6 100644
--- a/AppData/ComLib.cs
+++ b/AppData/ComLib.cs
@@ -504,10 +504,10 @@ namespace AppData
// cerco risposta come stack --> disegno...
var offOrder = deserializeOfflineOrder(rawAnsw);
// se ho in risposta 1 stack...
- if (offOrder.Stacks.Count == 1)
+ if (offOrder.Bunks.Count == 1)
{
// se ho 1 solo sheet
- var sheets = offOrder.Stacks[0].SheetList;
+ var sheets = offOrder.Bunks[0].SheetList;
if (sheets.Count == 1)
{
// controllo se ho CNC prog
diff --git a/NKC_WF/Controllers/BatchProcController.cs b/NKC_WF/Controllers/BatchProcController.cs
index 60c3616..5915186 100644
--- a/NKC_WF/Controllers/BatchProcController.cs
+++ b/NKC_WF/Controllers/BatchProcController.cs
@@ -23,6 +23,7 @@ namespace NKC_WF.Controllers
// in primis: controllo su redis SE HO una richiista CURRENT di processing...
string redKey = $"{ComLib.redOutPath}:CURR";
string redVal = memLayer.ML.getRSV(redKey);
+ string envNum = redVal;
// se c'รจ carico "la busta" come ID
if (!string.IsNullOrEmpty(redVal))
{
@@ -34,6 +35,8 @@ namespace NKC_WF.Controllers
try
{
answ = JsonConvert.DeserializeObject(redVal);
+ // aggiungo LA SUA ENV NUM!!!!
+ answ.envNum = envNum;
}
catch
{ }
diff --git a/NKC_SDK/Objects.cs b/NKC_SDK/Objects.cs
index 17fa6c4..8fbf350 100644
--- a/NKC_SDK/Objects.cs
+++ b/NKC_SDK/Objects.cs
@@ -166,9 +166,9 @@ namespace NKC_SDK
///
public string Drawing { get; set; }
///
/// Elenco Items da produrre x ordine
///
- public List Items { get; set; } = null;
+ public List PartList { get; set; } = null;
}
///
/// Struttura stack
@@ -166,9 +166,9 @@ namespace NKC_SDK
public string Drawing { get; set; }
///
- /// Elenco Items da produrre x ordine
+ /// Elenco Part da produrre x ordine
///